diff --git a/drivers/gpu/drm/tidss/tidss_dispc.c b/drivers/gpu/drm/tidss/tidss_dispc.c
index 1afd0d36baf8..60aba41eb183 100644
--- a/drivers/gpu/drm/tidss/tidss_dispc.c
+++ b/drivers/gpu/drm/tidss/tidss_dispc.c
@@ -1365,8 +1365,10 @@ int dispc_vp_set_clk_rate(struct dispc_device *dispc, u32 hw_videoport,
 			hw_videoport, rate);
 		return r;
 	}
+	dev_err(dispc->dev, "vp%d: set clk rate to %lu\n", hw_videoport, rate);
 
 	new_rate = clk_get_rate(dispc->vp_clk[hw_videoport]);
+	dev_err(dispc->dev, "vp%d: get clk rate %lu\n", hw_videoport, new_rate);
 
 	if (dispc_pclk_diff(rate, new_rate) > 5)
 		dev_warn(dispc->dev,
@@ -2872,6 +2874,7 @@ int dispc_init(struct tidss_device *tidss)
 	int r = 0;
 
 	dev_dbg(dev, "%s\n", __func__);
+	dev_err(dev, "%s\n", __func__);
 
 	feat = tidss->feat;
 
@@ -2978,11 +2981,13 @@ int dispc_init(struct tidss_device *tidss)
 		return PTR_ERR(dispc->fclk);
 	}
 	dev_dbg(dev, "DSS fclk %lu Hz\n", clk_get_rate(dispc->fclk));
+	dev_err(dev, "DSS fclk %lu Hz\n", clk_get_rate(dispc->fclk));
 
 	of_property_read_u32(dispc->dev->of_node, "max-memory-bandwidth",
 			     &dispc->memory_bandwidth_limit);
 
 	tidss->dispc = dispc;
 
+	dev_dbg(dev, "%s Done\n", __func__);
 	return 0;
 }
diff --git a/drivers/gpu/drm/tidss/tidss_drv.c b/drivers/gpu/drm/tidss/tidss_drv.c
index b2edeefabdd5..66db6016d019 100644
--- a/drivers/gpu/drm/tidss/tidss_drv.c
+++ b/drivers/gpu/drm/tidss/tidss_drv.c
@@ -134,6 +134,7 @@ static int tidss_probe(struct platform_device *pdev)
 	int irq;
 
 	dev_dbg(dev, "%s\n", __func__);
+	dev_err(dev, "%s\n", __func__);
 
 	tidss = devm_drm_dev_alloc(&pdev->dev, &tidss_driver,
 				   struct tidss_device, ddev);
@@ -146,12 +147,14 @@ static int tidss_probe(struct platform_device *pdev)
 	tidss->feat = of_device_get_match_data(dev);
 
 	platform_set_drvdata(pdev, tidss);
+	dev_err(dev, "%s: Check Point 1. \n", __func__);
 
 	ret = dispc_init(tidss);
 	if (ret) {
 		dev_err(dev, "failed to initialize dispc: %d\n", ret);
 		return ret;
 	}
+	dev_err(dev, "%s: Check Point 2. dispc_init done \n", __func__);
 
 	pm_runtime_enable(dev);
 
@@ -160,12 +163,14 @@ static int tidss_probe(struct platform_device *pdev)
 	dispc_runtime_resume(tidss->dispc);
 #endif
 
+	dev_err(dev, "%s: Check Point 3. modeset_init \n", __func__);
 	ret = tidss_modeset_init(tidss);
 	if (ret < 0) {
 		if (ret != -EPROBE_DEFER)
 			dev_err(dev, "failed to init DRM/KMS (%d)\n", ret);
 		goto err_runtime_suspend;
 	}
+	dev_err(dev, "%s: Check Point 4. modeset_init done\n", __func__);
 
 	irq = platform_get_irq(pdev, 0);
 	if (irq < 0) {
@@ -183,15 +188,17 @@ static int tidss_probe(struct platform_device *pdev)
 
 	drm_mode_config_reset(ddev);
 
+	dev_err(dev, "%s: Check Point 5. drv reg\n", __func__);
 	ret = drm_dev_register(ddev, 0);
 	if (ret) {
 		dev_err(dev, "failed to register DRM device\n");
 		goto err_irq_uninstall;
 	}
-
+	dev_err(dev, "%s: Check Point 6 \n", __func__);
 	drm_fbdev_generic_setup(ddev, 32);
 
 	dev_dbg(dev, "%s done\n", __func__);
+	dev_err(dev, "%s done\n", __func__);
 
 	return 0;
 
diff --git a/drivers/gpu/drm/tidss/tidss_kms.c b/drivers/gpu/drm/tidss/tidss_kms.c
index 09485c7f0d6f..d9e6e9fce4b5 100644
--- a/drivers/gpu/drm/tidss/tidss_kms.c
+++ b/drivers/gpu/drm/tidss/tidss_kms.c
@@ -136,12 +136,15 @@ static int tidss_dispc_modeset_init(struct tidss_device *tidss)
 						  &panel, &bridge);
 		if (ret == -ENODEV) {
 			dev_dbg(dev, "no panel/bridge for port %d\n", i);
+			dev_err(dev, "no panel/bridge for port %d\n", i);
 			continue;
 		} else if (ret) {
 			dev_dbg(dev, "port %d probe returned %d\n", i, ret);
+			dev_err(dev, "port %d probe returned %d\n", i, ret);
 			return ret;
 		}
 
+		dev_err(dev, "%s: %s Found.", __func__, ((panel == NULL) ? "Bridge" : "Panel"));
 		if (panel) {
 			u32 conn_type;
 
